==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/frm_main_datagrid.js <==
_me = frm_main_datagrid.prototype;
function frm_main_datagrid(){};

_me.__constructor = function(){
	this._parent._create('lister','obj_lister_item','lister');
	this._parent.lister._bind(this.list);
};

_me.__update = function(aFolder){
	if (!aFolder['aid'] || !aFolder['fid']) return;

	//vzdy refreshnout hlavicku DG
	this.list._refreshHeader = true;

    var aView = dataSet.get('datagrid_views',[aFolder['aid'],aFolder['fid']]);
    
	//defaultni hodnoty pro lister
	this._parent.lister._range(aView['offset']+this._parent.lister._list());
	this._parent.lister._value(aView['offset'],true); //VALUE

	gui.frm_main.main.list._serverSort(aFolder,aView['sort']['column'],aView['sort']['type']);
};

/**
 * @Note: funkce ktera zobrazuje a skryva quicksearch toolbar
 * @Date: 28.5.2007 11:39:16
 **/
_me._showsearch = function(sType,sFolder,bFocus){

	//if (this.search_item) this.search_item._destruct();
	if (this.list) this.list._SQLfilter = '';

	switch((sType = sType.toLowerCase())){
	case 'm': return;

	case 'ql':
	case 'c':
	case 't':
	case 'n':
	case 'j':
	case 'e':
	case 'f':
		addcss(this._main,'frm_main_datagrid_searchdiv');
		this._create("search_item","obj_item_search_"+sType,"search");
		break;
		
	default:
		removecss(this._main,'frm_main_datagrid_searchdiv');
		return;
	}

	//add functionality
	if (this.search_item){

		if (bFocus)
			this.search_item._focus();

		var me = this;
		this.search_item._onsearch = function(v){
			me.list._SQLfilter = v;
            me.list._serverSort();
		}
	}
};

_me._hidesearch = function(bNoUpdate){
    if (!this.search_item) return;

	this.search_item._destruct();
	removecss(this._main,'frm_main_datagrid_searchdiv');

    if (this.list && this.list._SQLfilter){
		this.list._SQLfilter = '';
		if(!bNoUpdate) this.list._serverSort();
	}
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/frm_main_datagrid.js <==
_me = frm_main_datagrid.prototype;
function frm_main_datagrid(){};

_me.__constructor = function(){
	this.list.info = this._parent._create('lister','obj_dginfo','lister');
};

_me.__update = function(aFolder){
	if (!aFolder['aid'] || !aFolder['fid']) return;

    var aView = dataSet.get('datagrid_views',[aFolder['aid'],aFolder['fid']]);
	this.list._serverSort(aFolder,aView['sort']['column'],aView['sort']['type']);
};

/**
 * @Note: funkce ktera zobrazuje a skryva quicksearch toolbar
 * @Date: 28.5.2007 11:39:16
 **/
_me._showsearch = function(sType,sFolder,bFocus){

	//if (this.search_item) this.search_item._destruct();
	if (this.list) this.list._SQLfilter = '';

	switch((sType = sType.toLowerCase())){
	case 'm': return;

	case 'ql':
	case 'c':
	case 't':
	case 'n':
	case 'j':
	case 'e':
	case 'f':
		addcss(this._main,'frm_main_datagrid_searchdiv');
		this._create("search_item","obj_item_search_"+sType,"search");
		break;
		
	default:
		removecss(this._main,'frm_main_datagrid_searchdiv');
		return;
	}

	//add functionality
	if (this.search_item){

		if (bFocus)
			this.search_item._focus();

		var me = this;
		this.search_item._onsearch = function(v){
			me.list._SQLfilter = v;
            me.list._serverSort();
		}
	}
};

_me._hidesearch = function(bNoUpdate){
    if (!this.search_item) return;

	this.search_item._destruct();
	removecss(this._main,'frm_main_datagrid_searchdiv');

    if (this.list && this.list._SQLfilter){
		this.list._SQLfilter = '';
		if(!bNoUpdate) this.list._serverSort();
	}
};
